@@ -25,9 +25,10 @@ from neutron_lib import exceptions
 def _validate_privileges(context, res_dict):
     if ('project_id' in res_dict and
             res_dict['project_id'] != context.project_id and
-            not context.is_admin):
+            not (context.is_admin or context.is_advsvc)):
         msg = _("Specifying 'project_id' or 'tenant_id' other than the "
-                "authenticated project in request requires admin privileges")
+                "authenticated project in request requires admin or advsvc "
+                "privileges")
         raise exc.HTTPBadRequest(msg)
 
 
@@ -58,6 +59,84 @@ def populate_project_info(attributes):
     return attributes
 
 
+def _fill_default(res_dict, attr_name, attr_spec):
+    # update res_dict[attr_name] record with the default value
+    # specified in attr_spec, taking into account default_overrides_none
+    if attr_spec.get('default_overrides_none'):
+        if res_dict.get(attr_name) is None:
+            res_dict[attr_name] = attr_spec.get('default')
+            return
+
+    res_dict[attr_name] = res_dict.get(attr_name,
+                                       attr_spec.get('default'))
+
+
+def _dict_populate_defaults(attr_value, attr_spec):
+    # attr_value: dict
+    # attr_spec: an attribute specification dict e.g.
+    # {
+    #      ...
+    #      'dict_populate_defaults': True,
+    #      'default_overrides_none': ,
+    #      'validate': {
+    #                 'type:dict': {
+    #                     'foo': {
+    #                         'default': FOO_DEFAULT,
+    #                         'type:values': [42, 43]
+    #                     },
+    #                     'bar': {
+    #                         'default': BAR_DEFAULT,
+    #                         'convert_to': converters.convert_to_boolean
+    #                     }
+    #                     'baz': {
+    #                         'dict_populate_defaults': True
+    #                         'default_overrides_none': True,
+    #                         'type:dict': {
+    #                             'baz_bar: {
+    #                                 'default': 77,
+    #                                 'type:boolean'
+    #                             },
+    #                             'baz_foo': {
+    #                                 'default': 88,
+    #                                 'type:boolean'
+    #                             }
+    #                         }
+    #                     }
+    #             }
+    #      }
+    # }
+    if not attr_spec.get(constants.DICT_POPULATE_DEFAULTS):
+        return attr_value
+
+    if attr_value is None or attr_value is constants.ATTR_NOT_SPECIFIED:
+        attr_value = {}
+
+    for rule_type, rule_content in attr_spec['validate'].items():
+        # we only recursively apply defaults for dict rules
+        if 'dict' not in rule_type:
+            continue
+        for key, key_validator in rule_content.items():
+            validator_name, _dummy, validator_params = (
+                validators._extract_validator(key_validator))
+
+            # recurse if required:
+            if 'dict' in validator_name:
+                value = _dict_populate_defaults(
+                    attr_value.get(key),
+                    {
+                        constants.DICT_POPULATE_DEFAULTS: key_validator.get(
+                            constants.DICT_POPULATE_DEFAULTS),
+                        'validate': {validator_name: validator_params}
+                    }
+                )
+                if value is not None:
+                    attr_value[key] = value
+
+            _fill_default(attr_value, key, key_validator)
+
+    return attr_value
+
+
 class AttributeInfo(object):
     """Provides operations on a resource's attribute map.
 
@@ -110,12 +189,18 @@ class AttributeInfo(object):
         """
         for attr, attr_vals in self.attributes.items():
             if attr_vals['allow_post']:
+                value = _dict_populate_defaults(
+                    res_dict.get(attr, constants.ATTR_NOT_SPECIFIED),
+                    attr_vals)
+                if value is not constants.ATTR_NOT_SPECIFIED:
+                    res_dict[attr] = value
+
                 if 'default' not in attr_vals and attr not in res_dict:
                     msg = _("Failed to parse request. Required "
                             "attribute '%s' not specified") % attr
                     raise exc_cls(msg)
-                res_dict[attr] = res_dict.get(attr,
-                                              attr_vals.get('default'))
+
+                _fill_default(res_dict, attr, attr_vals)
             elif check_allow_post:
                 if attr in res_dict:
                     msg = _("Attribute '%s' not allowed in POST") % attr
@@ -144,10 +229,10 @@ class AttributeInfo(object):
                 continue
             for rule in attr_vals['validate']:
                 validator = validators.get_validator(rule)
-                res = validator(res_dict[attr], attr_vals['validate'][rule])
-
+                res = validator(res_dict[attr],
+                                attr_vals['validate'][rule])
                 if res:
-                    msg_dict = dict(attr=attr, reason=res)
+                    msg_dict = {'attr': attr, 'reason': res}
                     msg = _("Invalid input for %(attr)s. "
                             "Reason: %(reason)s.") % msg_dict
                     raise exc_cls(msg)
@@ -212,3 +297,16 @@ def _core_resource_attributes():
 
 # populate core resources into singleton global
 RESOURCES = _core_resource_attributes()
+
+
+def retrieve_valid_sort_keys(attr_info):
+    """Retrieve sort keys from `attr_info` dict.
+
+    Iterate the `attr_info`, filter and return the attributes that are
+    defined with `is_sort_key=True`.
+
+    :param attr_info: The attribute dict for common neutron resource.
+    :returns: Set of sort keys.
+    """
+    return set(attr for attr, schema in attr_info.items()
+               if schema.get('is_sort_key', False))
