@@ -96,6 +96,7 @@ from neutron_lib.api.definitions import port_hints
 from neutron_lib.api.definitions import port_mac_address_override
 from neutron_lib.api.definitions import port_mac_address_regenerate
 from neutron_lib.api.definitions import port_numa_affinity_policy
+from neutron_lib.api.definitions import port_numa_affinity_policy_socket
 from neutron_lib.api.definitions import port_resource_request
 from neutron_lib.api.definitions import port_resource_request_groups
 from neutron_lib.api.definitions import port_security
@@ -145,6 +146,7 @@ from neutron_lib.api.definitions import standard_attr_segment
 from neutron_lib.api.definitions import stateful_security_group
 from neutron_lib.api.definitions import subnet
 from neutron_lib.api.definitions import subnet_dns_publish_fixed_ip
+from neutron_lib.api.definitions import subnet_external_network
 from neutron_lib.api.definitions import subnet_onboard
 from neutron_lib.api.definitions import subnet_segmentid_enforce
 from neutron_lib.api.definitions import subnet_segmentid_writable
@@ -153,12 +155,14 @@ from neutron_lib.api.definitions import subnetpool
 from neutron_lib.api.definitions import subnetpool_prefix_ops
 from neutron_lib.api.definitions import taas
 from neutron_lib.api.definitions import tag_ports_during_bulk_creation
+from neutron_lib.api.definitions import tap_mirror
 from neutron_lib.api.definitions import trunk
 from neutron_lib.api.definitions import trunk_details
 from neutron_lib.api.definitions import uplink_status_propagation
 from neutron_lib.api.definitions import vlan_filter
 from neutron_lib.api.definitions import vlantransparent
 from neutron_lib.api.definitions import vpn
+from neutron_lib.api.definitions import vpn_aes_ccm_gcm
 from neutron_lib.api.definitions import vpn_endpoint_groups
 from neutron_lib.api.definitions import vpn_flavors
 
@@ -250,6 +254,7 @@ _ALL_API_DEFINITIONS = {
     port_mac_address_override,
     port_mac_address_regenerate,
     port_numa_affinity_policy,
+    port_numa_affinity_policy_socket,
     port_resource_request,
     port_resource_request_groups,
     port_security,
@@ -298,6 +303,7 @@ _ALL_API_DEFINITIONS = {
     stateful_security_group,
     subnet,
     subnet_dns_publish_fixed_ip,
+    subnet_external_network,
     subnet_onboard,
     subnet_segmentid_enforce,
     subnet_segmentid_writable,
@@ -306,12 +312,14 @@ _ALL_API_DEFINITIONS = {
     subnetpool_prefix_ops,
     taas,
     tag_ports_during_bulk_creation,
+    tap_mirror,
     trunk,
     trunk_details,
     uplink_status_propagation,
     vlan_filter,
     vlantransparent,
     vpn,
+    vpn_aes_ccm_gcm,
     vpn_endpoint_groups,
     vpn_flavors,
 }
