@@ -41,10 +41,48 @@ VPN_ENCRYPTION_ALGORITHM_3DES = '3des'
 VPN_ENCRYPTION_ALGORITHM_AES_128 = 'aes-128'
 VPN_ENCRYPTION_ALGORITHM_AES_192 = 'aes-192'
 VPN_ENCRYPTION_ALGORITHM_AES_256 = 'aes-256'
+VPN_ENCRYPTION_ALGORITHM_AES_128_CCM_8 = 'aes-128-ccm-8'
+VPN_ENCRYPTION_ALGORITHM_AES_192_CCM_8 = 'aes-192-ccm-8'
+VPN_ENCRYPTION_ALGORITHM_AES_256_CCM_8 = 'aes-256-ccm-8'
+VPN_ENCRYPTION_ALGORITHM_AES_128_CCM_12 = 'aes-128-ccm-12'
+VPN_ENCRYPTION_ALGORITHM_AES_192_CCM_12 = 'aes-192-ccm-12'
+VPN_ENCRYPTION_ALGORITHM_AES_256_CCM_12 = 'aes-256-ccm-12'
+VPN_ENCRYPTION_ALGORITHM_AES_128_CCM_16 = 'aes-128-ccm-16'
+VPN_ENCRYPTION_ALGORITHM_AES_192_CCM_16 = 'aes-192-ccm-16'
+VPN_ENCRYPTION_ALGORITHM_AES_256_CCM_16 = 'aes-256-ccm-16'
+VPN_ENCRYPTION_ALGORITHM_AES_128_GCM_8 = 'aes-128-gcm-8'
+VPN_ENCRYPTION_ALGORITHM_AES_192_GCM_8 = 'aes-192-gcm-8'
+VPN_ENCRYPTION_ALGORITHM_AES_256_GCM_8 = 'aes-256-gcm-8'
+VPN_ENCRYPTION_ALGORITHM_AES_128_GCM_12 = 'aes-128-gcm-12'
+VPN_ENCRYPTION_ALGORITHM_AES_192_GCM_12 = 'aes-192-gcm-12'
+VPN_ENCRYPTION_ALGORITHM_AES_256_GCM_12 = 'aes-256-gcm-12'
+VPN_ENCRYPTION_ALGORITHM_AES_128_GCM_16 = 'aes-128-gcm-16'
+VPN_ENCRYPTION_ALGORITHM_AES_192_GCM_16 = 'aes-192-gcm-16'
+VPN_ENCRYPTION_ALGORITHM_AES_256_GCM_16 = 'aes-256-gcm-16'
 
 VPN_SUPPORTED_ENCRYPTION_ALGORITHMS = [
-    VPN_ENCRYPTION_ALGORITHM_3DES, VPN_ENCRYPTION_ALGORITHM_AES_128,
-    VPN_ENCRYPTION_ALGORITHM_AES_192, VPN_ENCRYPTION_ALGORITHM_AES_256,
+    VPN_ENCRYPTION_ALGORITHM_3DES,
+    VPN_ENCRYPTION_ALGORITHM_AES_128,
+    VPN_ENCRYPTION_ALGORITHM_AES_192,
+    VPN_ENCRYPTION_ALGORITHM_AES_256,
+    VPN_ENCRYPTION_ALGORITHM_AES_128_CCM_8,
+    VPN_ENCRYPTION_ALGORITHM_AES_192_CCM_8,
+    VPN_ENCRYPTION_ALGORITHM_AES_256_CCM_8,
+    VPN_ENCRYPTION_ALGORITHM_AES_128_CCM_12,
+    VPN_ENCRYPTION_ALGORITHM_AES_192_CCM_12,
+    VPN_ENCRYPTION_ALGORITHM_AES_256_CCM_12,
+    VPN_ENCRYPTION_ALGORITHM_AES_128_CCM_16,
+    VPN_ENCRYPTION_ALGORITHM_AES_192_CCM_16,
+    VPN_ENCRYPTION_ALGORITHM_AES_256_CCM_16,
+    VPN_ENCRYPTION_ALGORITHM_AES_128_GCM_8,
+    VPN_ENCRYPTION_ALGORITHM_AES_192_GCM_8,
+    VPN_ENCRYPTION_ALGORITHM_AES_256_GCM_8,
+    VPN_ENCRYPTION_ALGORITHM_AES_128_GCM_12,
+    VPN_ENCRYPTION_ALGORITHM_AES_192_GCM_12,
+    VPN_ENCRYPTION_ALGORITHM_AES_256_GCM_12,
+    VPN_ENCRYPTION_ALGORITHM_AES_128_GCM_16,
+    VPN_ENCRYPTION_ALGORITHM_AES_192_GCM_16,
+    VPN_ENCRYPTION_ALGORITHM_AES_256_GCM_16,
 ]
 
 # VPN DPD action constants
@@ -88,9 +126,30 @@ VPN_SUPPORTED_LIFETIME_UNITS = [
 VPN_PFS_GROUP2 = 'group2'
 VPN_PFS_GROUP5 = 'group5'
 VPN_PFS_GROUP14 = 'group14'
+VPN_PFS_GROUP15 = 'group15'
+VPN_PFS_GROUP16 = 'group16'
+VPN_PFS_GROUP17 = 'group17'
+VPN_PFS_GROUP18 = 'group18'
+VPN_PFS_GROUP19 = 'group19'
+VPN_PFS_GROUP20 = 'group20'
+VPN_PFS_GROUP21 = 'group21'
+VPN_PFS_GROUP22 = 'group22'
+VPN_PFS_GROUP23 = 'group23'
+VPN_PFS_GROUP24 = 'group24'
+VPN_PFS_GROUP25 = 'group25'
+VPN_PFS_GROUP26 = 'group26'
+VPN_PFS_GROUP27 = 'group27'
+VPN_PFS_GROUP28 = 'group28'
+VPN_PFS_GROUP29 = 'group29'
+VPN_PFS_GROUP30 = 'group30'
+VPN_PFS_GROUP31 = 'group31'
 
 VPN_SUPPORTED_PFSES = [
-    VPN_PFS_GROUP2, VPN_PFS_GROUP5, VPN_PFS_GROUP14,
+    VPN_PFS_GROUP2, VPN_PFS_GROUP5, VPN_PFS_GROUP14, VPN_PFS_GROUP15,
+    VPN_PFS_GROUP16, VPN_PFS_GROUP17, VPN_PFS_GROUP18, VPN_PFS_GROUP19,
+    VPN_PFS_GROUP20, VPN_PFS_GROUP21, VPN_PFS_GROUP22, VPN_PFS_GROUP23,
+    VPN_PFS_GROUP24, VPN_PFS_GROUP25, VPN_PFS_GROUP26, VPN_PFS_GROUP27,
+    VPN_PFS_GROUP28, VPN_PFS_GROUP29, VPN_PFS_GROUP30, VPN_PFS_GROUP31,
 ]
 
 # VPN IKE version constants
@@ -113,10 +172,13 @@ VPN_AUTH_ALGORITHM_SHA1 = 'sha1'
 VPN_AUTH_ALGORITHM_SHA256 = 'sha256'
 VPN_AUTH_ALGORITHM_SHA384 = 'sha384'
 VPN_AUTH_ALGORITHM_SHA512 = 'sha512'
+VPN_AUTH_ALGORITHM_AES_XCBC = 'aes-xcbc'
+VPN_AUTH_ALGORITHM_AES_CMAC = 'aes-cmac'
 
 VPN_SUPPORTED_AUTH_ALGORITHMS = [
     VPN_AUTH_ALGORITHM_SHA1, VPN_AUTH_ALGORITHM_SHA256,
     VPN_AUTH_ALGORITHM_SHA384, VPN_AUTH_ALGORITHM_SHA512,
+    VPN_AUTH_ALGORITHM_AES_XCBC, VPN_AUTH_ALGORITHM_AES_CMAC,
 ]
 
 # VPN phase1 negotiation mode constants
