@@ -62,10 +62,6 @@ DEVICE_OWNER_AGENT_GW = (DEVICE_OWNER_NETWORK_PREFIX +
 DEVICE_OWNER_ROUTER_SNAT = (DEVICE_OWNER_NETWORK_PREFIX +
                             "router_centralized_snat")
 DEVICE_OWNER_ROUTED = (DEVICE_OWNER_NETWORK_PREFIX + "routed")
-# TODO(johnsom) Remove after these stop being used. Neutron-LBaaS is now
-#               retired (train) and these should no longer be necessary.
-DEVICE_OWNER_LOADBALANCER = DEVICE_OWNER_NEUTRON_PREFIX + "LOADBALANCER"
-DEVICE_OWNER_LOADBALANCERV2 = DEVICE_OWNER_NEUTRON_PREFIX + "LOADBALANCERV2"
 
 # Device owner for distributed services (e.g OVN Metadata/DHCP).
 DEVICE_OWNER_DISTRIBUTED = DEVICE_OWNER_NETWORK_PREFIX + "distributed"
@@ -83,6 +79,23 @@ ROUTER_INTERFACE_OWNERS_SNAT = (DEVICE_OWNER_ROUTER_INTF,
                                 DEVICE_OWNER_DVR_INTERFACE,
                                 DEVICE_OWNER_ROUTER_SNAT)
 
+DEVICE_OWNER_DEFAULT = ''
+NO_PROVISIONING_BLOCKS_OWNERS = (DEVICE_OWNER_DEFAULT,
+                                 DEVICE_OWNER_DVR_INTERFACE,
+                                 DEVICE_OWNER_HA_REPLICATED_INT,
+                                 DEVICE_OWNER_ROUTER_INTF,
+                                 DEVICE_OWNER_ROUTER_GW,
+                                 DEVICE_OWNER_ROUTER_SNAT,
+                                 DEVICE_OWNER_DHCP,
+                                 DEVICE_OWNER_AGENT_GW,
+                                 DEVICE_OWNER_ROUTER_HA_INTF,
+                                 DEVICE_OWNER_FLOATINGIP)
+
+DHCP_CONFIG_NOT_REQUIRED_OWNERS = (DEVICE_OWNER_ROUTER_HA_INTF,
+                                   DEVICE_OWNER_FLOATINGIP,
+                                   DEVICE_OWNER_DHCP,
+                                   DEVICE_OWNER_DISTRIBUTED)
+
 DEVICE_ID_RESERVED_DHCP_PORT = 'reserved_dhcp_port'
 
 FLOATINGIP_KEY = '_floatingips'
@@ -104,8 +117,14 @@ IPv4_ANY = '0.0.0.0/0'
 IPv6_ANY = '::/0'
 IP_ANY = {IP_VERSION_4: IPv4_ANY, IP_VERSION_6: IPv6_ANY}
 
+IPv4_NETWORK_BROADCAST = "255.255.255.255"
+
 IPv6_LLA_PREFIX = 'fe80::/64'
 
+# All_DHCP_Relay_Agents_and_Servers
+# [RFC8415] https://datatracker.ietf.org/doc/html/rfc8415
+IPv6_ALL_DHCP_RELAY_AGENTS_AND_SERVERS = "ff02::1:2"
+
 DHCP_CLIENT_PORT = 68
 DHCP_RESPONSE_PORT = 67
 DHCPV6_CLIENT_PORT = 546
@@ -315,6 +334,7 @@ ACTIVE_PENDING_STATUSES = (
 TYPE_FLAT = 'flat'
 TYPE_GENEVE = 'geneve'
 TYPE_GRE = 'gre'
+TYPE_GRE_IP6 = 'ip6gre'
 TYPE_LOCAL = 'local'
 TYPE_VXLAN = 'vxlan'
 TYPE_VLAN = 'vlan'
@@ -582,6 +602,7 @@ RPC_NAMESPACE_RESOURCES = None
 
 # Default network MTU value when not configured
 DEFAULT_NETWORK_MTU = 1500
+IPV4_MIN_MTU = 68
 IPV6_MIN_MTU = 1280
 
 ROUTER_MARK_MASK = "0xffff"
@@ -666,6 +687,7 @@ NO_ACTIVE_BINDING = 'no_active_binding'
 EXT_PARENT_PREFIX = 'ext_parent'
 
 RP_BANDWIDTHS = 'resource_provider_bandwidths'
+RP_HYPERVISORS = 'resource_provider_hypervisors'
 RP_INVENTORY_DEFAULTS = 'resource_provider_inventory_defaults'
 RP_PP_WITHOUT_DIRECTION = (
     'resource_provider_packet_processing_without_direction')
@@ -677,8 +699,12 @@ RP_PP_INVENTORY_DEFAULTS = (
 PORT_NUMA_POLICY_REQUIRED = 'required'
 PORT_NUMA_POLICY_PREFERRED = 'preferred'
 PORT_NUMA_POLICY_LEGACY = 'legacy'
-PORT_NUMA_POLICIES = (PORT_NUMA_POLICY_REQUIRED, PORT_NUMA_POLICY_PREFERRED,
-                      PORT_NUMA_POLICY_LEGACY)
+PORT_NUMA_POLICY_SOCKET = 'socket'
+PORT_NUMA_POLICIES = (PORT_NUMA_POLICY_REQUIRED,
+                      PORT_NUMA_POLICY_PREFERRED,
+                      PORT_NUMA_POLICY_LEGACY,
+                      PORT_NUMA_POLICY_SOCKET,
+                      )
 
 # RBAC Sharing Actions
 ACCESS_SHARED = 'access_as_shared'
