@@ -23,7 +23,13 @@ IP_ADDR_FIELD_SIZE = 64  # large enough to hold a v4 or v6 address
 MAC_ADDR_FIELD_SIZE = 32
 RESOURCE_TYPE_FIELD_SIZE = 255
 FQDN_FIELD_SIZE = 255
+AZ_HINTS_DB_LEN = 255
 
 # Alembic branches
 EXPAND_BRANCH = 'expand'
 CONTRACT_BRANCH = 'contract'
+
+# Maximum value integer can take in MySQL and PostgreSQL
+# In SQLite integer can be stored in 1, 2, 3, 4, 6, or 8 bytes,
+# but here it will be limited by this value for consistency.
+DB_INTEGER_MAX_VALUE = 2 ** 31 - 1
