@@ -16,14 +16,6 @@
 TRAIT_PREFIX_VNIC_TYPE = 'VNIC_TYPE_'
 TRAIT_PREFIX_PHYSNET = 'PHYSNET_'
 
-# TODO(przszc): Remove resource classes constants with next major release of
-# neutron-lib. There were only a few occurrences in neutron source code where
-# those constants were used, and all of them were replaced with
-# os-resource-classes lib.
-# **DEPRECATED** resource classes
-CLASS_NET_BW_EGRESS_KBPS = 'NET_BW_EGR_KILOBIT_PER_SEC'
-CLASS_NET_BW_INGRESS_KBPS = 'NET_BW_IGR_KILOBIT_PER_SEC'
-
 # Optionally reported inventory parameters. Mandatory parameters like 'total'
 # are left out intentionally. See also:
 # https://docs.openstack.org/api-ref/placement
@@ -35,3 +27,7 @@ INVENTORY_OPTIONS = set([
     'reserved',
     'step_size',
     ])
+
+# Tunnelled networks resource provider default name.
+RP_TUNNELLED = 'rp_tunnelled'
+TRAIT_NETWORK_TUNNEL = 'CUSTOM_NETWORK_TUNNEL_PROVIDER'
