@@ -1,4 +1,4 @@
-# Copyright 2021 Ericsson Software Technology
+# Copyright 2023 Canonical Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -12,10 +12,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from neutron_lib.api.definitions import l3_multi_ext_gw
+from neutron_lib.api.definitions import l3_ext_gw_multihoming
 from neutron_lib.tests.unit.api.definitions import base
 
 
-class L3MultipleExternalGatewaysDefinitionTestCase(
+class L3ExternalGatewayMultihomingDefinitionTestCase(
         base.DefinitionBaseTestCase):
-    extension_module = l3_multi_ext_gw
+    extension_module = l3_ext_gw_multihoming
