@@ -595,14 +595,6 @@ class TestAttributeValidation(base.BaseTestCase):
                              'destination': '100.0.0.0/8'},
                             {'nexthop': '10.0.2.20',
                              'destination': '100.0.0.0/8'}],
-                           [{'nexthop': '10.0.2.20',
-                             'destination': '101.0.0.0/8',
-                             'bfd_monitor_id':
-                                 'uuid'}],
-                           [{'nexthop': '10.0.2.20',
-                             'destination': '101.0.0.0/8',
-                             'bfd_monitor_id':
-                                 None}],
                            [None],
                            None]
         for host_routes in hostroute_pools:
@@ -614,20 +606,7 @@ class TestAttributeValidation(base.BaseTestCase):
                            [{'nexthop': '10.0.2.20',
                              'destination': '100.0.0.0/8'},
                             {'nexthop': '10.0.2.20',
-                             'destination': '101.0.0.0/8'}],
-                           [{'nexthop': '10.0.2.20',
-                             'destination': '100.0.0.0/24'},
-                            {'nexthop': '10.0.2.20',
-                             'destination': '101.0.0.0/8',
-                             'bfd_monitor_id':
-                                 '469e4b94-f607-11eb-a9a2-038e2b6c9f81'}],
-                           [{'nexthop': '10.0.2.20',
-                             'destination': '101.0.0.0/8',
-                             'bfd_monitor_id':
-                                 '469e4b94-f607-11eb-a9a2-038e2b6c9f81'},
-                            {'nexthop': '10.0.2.20',
-                             'destination': '100.0.0.0/24'}]
-                           ]
+                             'destination': '101.0.0.0/8'}]]
         for host_routes in hostroute_pools:
             msg = validators.validate_hostroutes(host_routes, None)
             self.assertIsNone(msg)
@@ -981,12 +960,12 @@ class TestAttributeValidation(base.BaseTestCase):
 
         items = [['a', 'b'], ['c', 'd'], ['a', 'b']]
         msg = validators._validate_list_of_items(mock.Mock(), items)
-        error = "Duplicate items in the list: '%s'" % ['a', 'b']
+        error = "Duplicate items in the list: '%s'" % str(['a', 'b'])
         self.assertEqual(error, msg)
 
         items = [{'a': 'b'}, {'c': 'd'}, {'a': 'b'}]
         msg = validators._validate_list_of_items(mock.Mock(), items)
-        error = "Duplicate items in the list: '%s'" % {'a': 'b'}
+        error = "Duplicate items in the list: '%s'" % str({'a': 'b'})
         self.assertEqual(error, msg)
 
     def test_validate_dict_type(self):
@@ -1299,6 +1278,22 @@ class TestValidateIPSubnetNone(base.BaseTestCase):
 
 class TestPortRangeValidation(base.BaseTestCase):
 
+    def test_valid_port_specific_range(self):
+        result = validators.validate_port_range_or_none("4:5",
+                                                        [1, 65535])
+        self.assertIsNone(result)
+
+    def test_invalid_port_specific_range(self):
+        result = validators.validate_port_range_or_none("4:500000",
+                                                        [1, 65535])
+        self.assertEqual(u"Invalid port: 500000", result)
+
+    def test_invalid_port_for_specific_range(self):
+        result = validators.validate_port_range_or_none("0:10",
+                                                        [1, 65535])
+        self.assertEqual(u"Invalid port: 0, the port must be in"
+                         u" the range [1, 65535]", result)
+
     def test_valid_port(self):
         result = validators.validate_port_range_or_none("80")
         self.assertIsNone(result)
